pub struct TransformSink<'a, S> {
inner: &'a mut S,
matrix: Option<FontMatrix>,
scale: Option<Fixed>,
}Expand description
Command sink adapter that applies a matrix and optional scale.
Fields
inner: &'a mut Smatrix: Option<FontMatrix>scale: Option<Fixed>Implementations
Sourceimpl<'a, S> TransformSink<'a, S>
impl<'a, S> TransformSink<'a, S>
Sourcepub fn new(sink: &'a mut S, transform: Transform) -> Self
pub fn new(sink: &'a mut S, transform: Transform) -> Self
Creates a new sink for the given transform.
Sourcepub fn from_matrix_scale(
sink: &'a mut S,
matrix: FontMatrix,
scale: Option<Fixed>,
) -> Self
pub fn from_matrix_scale( sink: &'a mut S, matrix: FontMatrix, scale: Option<Fixed>, ) -> Self
Creates a new sink for the given matrix and optional scale.
fn transform(&self, x: Fixed, y: Fixed) -> (Fixed, Fixed)