pub struct NopFilterSink<'a, S> {
is_open: bool,
start: Option<(Fixed, Fixed)>,
pending_element: Option<PendingElement>,
inner: &'a mut S,
}Expand description
Command sink adapter that suppresses degenerate move and line commands.
FreeType avoids emitting empty contours and zero length lines to prevent artifacts when stem darkening is enabled. We don’t support stem darkening because it’s not enabled by any of our clients but we remove the degenerate elements regardless to match the output.
Fields
is_open: boolstart: Option<(Fixed, Fixed)>pending_element: Option<PendingElement>inner: &'a mut SImplementations
Sourceimpl<'a, S> NopFilterSink<'a, S>where
S: CommandSink,
impl<'a, S> NopFilterSink<'a, S>where
S: CommandSink,