pub trait CharstringContext {
// Required methods
fn kind(&self) -> CharstringKind;
fn seac_components(
&self,
base_code: i32,
accent_code: i32,
) -> Result<[&[u8]; 2], Error>;
fn global_subr(&self, index: i32) -> Result<&[u8], Error>;
fn subr(&self, index: i32) -> Result<&[u8], Error>;
// Provided method
fn weight_vector(&self) -> &[Fixed] { ... }
}Expand description
Trait that provides context for charstring evaluation.
Required Methods
Sourcefn kind(&self) -> CharstringKind
fn kind(&self) -> CharstringKind
Returns the type of the charstring.
Sourcefn seac_components(
&self,
base_code: i32,
accent_code: i32,
) -> Result<[&[u8]; 2], Error>
fn seac_components( &self, base_code: i32, accent_code: i32, ) -> Result<[&[u8]; 2], Error>
Returns the base and accent charstrings for the seac (standard
encoded accented character) operator.
Provided Methods
Sourcefn weight_vector(&self) -> &[Fixed]
fn weight_vector(&self) -> &[Fixed]
Returns the current active weight vector for a multiple master font.